package page_votes

import (
	"code.electrolab.fr/it/vote.electrolab.fr/app/server"
	"code.electrolab.fr/it/vote.electrolab.fr/app/server/pages/common"
	"code.electrolab.fr/it/vote.electrolab.fr/model"
	"context"
	"log"
	"net/http"
)

var (
	templateIndex     = common.MustParseTemplate(TEMPLATE_INDEX_STR)
	templateForbidden = common.MustParseTemplate(TEMPLATE_FORBIDDEN_STR)
)

func RegisterRoutes(mux *http.ServeMux, app *server.App) {
	mux.Handle("/events/Electrolab-AG-2020/votes", server.NewAppHandler(app, handleGetVotes))
}

func handleGetVotes(app *server.App, ctx context.Context, w http.ResponseWriter, r *http.Request) {
	var (
		err               error
		templateIndexVars = new(TemplateIndexVars)
	)

	templateIndexVars.PageTitle = "Vote Électrolab"

	userUuid, voterFullName, err := common.GetVoterInfo(app, ctx, r)
	if err != nil {
		// Token is not valid
		w.WriteHeader(http.StatusForbidden)
		templateForbidden.Execute(w, nil)
		return
	} else {
		templateIndexVars.VoterPrivateToken = r.FormValue("private_token")
		templateIndexVars.VoterFullname = voterFullName
	}

	// Token is valid, download the questions

	templateIndexVars.Questions, err = model.FetchAllQuestions(app.Context, app.Service.DB, userUuid)
	if err != nil {
		// Query has an error
		log.Printf("Query error 2: %s", err.Error())
		w.WriteHeader(http.StatusInternalServerError)
		return
	}

	err = templateIndex.Execute(w, templateIndexVars)
	if err != nil {
		// Template has an error
		log.Printf("Template execution error: %s", err.Error())
		w.WriteHeader(http.StatusInternalServerError)
		return
	}

}
